@@ -113,6 +113,11 @@ def get_args() -> (str, str, argparse.Namespace):
             help="Specify Ansible playbook for custom configuration (Path to main.yml file)",
         )
         prov_parser.add_argument("-h", "--help", action="store_true")
+        prov_parser.add_argument(
+            "--no-config",
+            action="store_true",
+            help="Do not run any configuration (except custom)",
+        )
 
     args = parser.parse_args()
 
@@ -148,18 +153,32 @@ def get_args() -> (str, str, argparse.Namespace):
 
     # not specifying anything other than setup parse config
     if args.setup and not (args.minimal or args.full or args.custom):
+        if args.no_config:
+            args.minimal = False
+            args.full = False
+
         if "config" in cfg:
             # This is default behavior so don't really have to do this
             # first set is mutually exclusive, but custom can be used with any
-            if "bare" in cfg["config"] and cfg["config"]["bare"] == True:
+            if "none" in cfg["config"] and cfg["config"]["none"] == True:
+                args.no_config = True
+            elif "bare" in cfg["config"] and cfg["config"]["bare"] == True:
                 args.minimal = False
                 args.full = False
             elif "minimal" in cfg["config"] and cfg["config"]["minimal"] == True:
                 args.minimal = True
                 args.full = False
             elif "full" in cfg["config"] and cfg["config"]["minimal"] == True:
+                args.minimal = False
+                args.full = False
                 args.minimal = False
                 args.full = True
+            elif (
+                ("bare" in cfg["config"] and cfg["config"]["bare"] == False)
+                and ("minimal" in cfg["config"] and cfg["config"]["minimal"] == False)
+                and ("full" in cfg["config"] and cfg["config"]["minimal"] == False)
+            ):
+                args.no_config = True
 
             if "custom" in cfg["config"]:
                 args.minimal = False
@@ -484,7 +503,9 @@ def main(args: argparse.Namespace = None, override_teardown: bool = False) -> No
     save_hosts(args.provider, new_hosts)
 
     # Ansible configuration
-    if args.full:
+    if args.no_config:
+        pass
+    elif args.full:
         run_playbook("full.yml", args.user)
     elif args.minimal:
         run_playbook("minimal.yml", args.user)
